durationtools.duration_tokens_to_duration_pairs
===============================================

.. autofunction:: abjad.tools.durationtools.duration_tokens_to_duration_pairs.duration_tokens_to_duration_pairs
